# Module <code>example_pump_assets</code>

This module contains an example of source data for pumps and their associated assets with the transformations
into CDF Assets.

The dataset is taken from [Collections Pump](https://data.bendoregon.gov/maps/collections-pump).

From the source:
```
 The purpose of this dataset is to show the line configurations associated with the pumps operating at the lift stations around the City's Collection system.
```

This is the basis for the practical guide to data modeling in CDF found in the [Cognite Documentation](https://pr-1865.docs.preview.cogniteapp.com/cdf/dm/dm_guides/dm_create_asset_hierarchy).
